# WOMBAT API

The WOMBAT framework relies on a set of base data classes powered by the attrs
library and a series of simulation classes and methods to perform all the operations.

To make it easier for users, there is also a simulation interface provided.

## Package Hierarchy

```{image} ../images/package_hierarchy.svg
:alt:
:align: center
```

## Class Hierarchy

```{image} ../images/class_diagram.svg
:alt:
:align: center
:width: 2400px
```
